<?php
/**
 * @file
 * Commerce Availability admin settings form code:
 * - define form
 * - validate
 */

function _ca_getOptions($value, $entity_type, $field_type) {
    $fields = field_info_fields();
    $options = array('-- empty --');
    foreach ($fields as $field_name => $field_data) {
        if (!empty($field_data['bundles'][$entity_type])) {
            $types_product = $field_data['bundles'][$entity_type];
            if (in_array($value, $types_product) && $field_data['type'] == $field_type) {
                $options[$field_name] = $field_name;
            }
        }
    }
    if (count($options) > 1) {
        unset($options[0]);
    }
    return $options;
}

function _ca_getLineItemDateTimeFields($form, &$form_state) {
    $av_type_l_value = isset($form_state['values']['av_type_l']) ? $form_state['values']['av_type_l'] : '';
    $options = _ca_getOptions($av_type_l_value, 'commerce_line_item', 'datetime');
    $form['line_item_fieldset']['av_f_name_l']['#options'] = $options;
    return $form['av_f_name_l'];
}

function _ca_getProductCalendarFields($form, &$form_state) {
    $av_type_p_value = isset($form_state['values']['av_type_p']) ? $form_state['values']['av_type_p'] : '';
    $options = _ca_getOptions($av_type_p_value, 'commerce_product', 'availability_calendar');
    $form['product_fieldset']['av_f_name_p']['#options'] = $options;
    return $form['av_f_name_p'];
}

function commerce_availability_admin($form, &$form_state) {

    $form['line_item_fieldset'] = array(
        '#type' => 'fieldset',
        '#collapsible' => FALSE,
        '#title' => t('Line item field selection'),
        '#attributes' => array('id' => 'line_item_fieldset'),
    );
    $form['product_fieldset'] = array(
        '#type' => 'fieldset',
        '#collapsible' => FALSE,
        '#title' => t('Product field selection'),
        '#attributes' => array('id' => 'product_fieldset'),
    );

    $line_type_options = commerce_line_item_type_get_name();
    $av_type_l = variable_get('av_type_l', 0);
    $default_av_type_l = !empty($av_type_l) ? array($av_type_l => $av_type_l) : array();
    $form['line_item_fieldset']['av_type_l'] = array(
        '#type' => 'select',
        '#title' => t('Select the line item type with event datetime field'),
        '#default_value' => $default_av_type_l,
        '#options' => $line_type_options,
        '#required' => TRUE,
        '#empty_option' => '-- empty --',
        '#empty_value' => 0,
        '#ajax' => array(
            'event' => 'change',
            'wrapper' => 'av_f_name_l_wrapper',
            'callback' => '_ca_getLineItemDateTimeFields',
            'method' => 'replace',
        ),
    );
    $av_f_name_l = variable_get('av_f_name_l', 0);
    $default_av_f_name_l = !empty($av_f_name_l) ? array($av_f_name_l => $av_f_name_l) : array();
    $form['line_item_fieldset']['av_f_name_l'] = array(
        '#type' => 'select',
        '#title' => t('Line item event field'),
        '#prefix' => '<div id="av_f_name_l_wrapper">',
        '#suffix' => '</div>',
        '#required' => TRUE,
        '#empty_option' => '-- empty --',
        '#empty_value' => 0,
        '#validated' => TRUE,
        '#options' => _ca_getOptions($av_type_l, 'commerce_line_item', 'datetime'),
        '#default_value' => variable_get('av_f_name_l', 0),
    );

    $product_type_options = commerce_product_type_get_name();
    $av_type_p = variable_get('av_type_p', 0);
    $default_av_type_p = !empty($av_type_p) ? array($av_type_p => $av_type_p) : array();
    $form['product_fieldset']['av_type_p'] = array(
        '#type' => 'select',
        '#title' => t('Select the product type with an availability calendar'),
        '#default_value' => $default_av_type_p,
        '#options' => $product_type_options,
        '#required' => TRUE,
        '#empty_option' => '-- empty --',
        '#empty_value' => 0,
        '#ajax' => array(
            'event' => 'change',
            'wrapper' => 'av_f_name_p_wrapper',
            'callback' => '_ca_getProductCalendarFields',
            'method' => 'replace',
        ),
    );
    $av_f_name_p = variable_get('av_f_name_p', 0);
    $default_av_f_name_p = !empty($av_f_name_p) ? array($av_f_name_p => $av_f_name_p) : array();
    $form['product_fieldset']['av_f_name_p'] = array(
        '#type' => 'select',
        '#title' => t('Product calendar field'),
        '#prefix' => '<div id="av_f_name_p_wrapper">',
        '#suffix' => '</div>',
        '#required' => TRUE,
        '#empty_option' => '-- empty --',
        '#empty_value' => 0,
        '#validated' => TRUE,
        '#options' => _ca_getOptions($av_type_p, 'commerce_product', 'availability_calendar'),
        '#default_value' => variable_get('av_f_name_p', 0),
    );

    $form['av_n_days_before'] = array(
        '#type' => 'textfield',
        '#title' => t('Days before'),
        '#default_value' => variable_get('av_n_days_before', 2),
        '#size' => 2,
        '#maxlength' => 2,
        '#description' => t('Buffer of days before the event'),
        '#required' => TRUE,
    );
    $form['av_n_days_after'] = array(
        '#type' => 'textfield',
        '#title' => t('Days after'),
        '#default_value' => variable_get('av_n_days_after', 2),
        '#size' => 2,
        '#maxlength' => 2,
        '#description' => t('Buffer of days after the event'),
        '#required' => TRUE,
    );
    $form['av_n_initial_buffer'] = array(
        '#type' => 'textfield',
        '#title' => t('Initial buffer'),
        '#default_value' => variable_get('av_n_initial_buffer', 3),
        '#size' => 2,
        '#maxlength' => 2,
        '#description' => t('Buffer of days after current day'),
        '#required' => TRUE,
    );
    $form['av_n_festive_day'] = array(
        '#type' => 'textfield',
        '#title' => t('Festive day'),
        '#default_value' => variable_get('av_n_festive_day', 7),
        '#size' => 2,
        '#maxlength' => 2,
        '#description' => t('Number of week of the festive day (0 to invalidate)'),
        '#required' => TRUE,
    );
    $form['av_c_hide_quantity'] = array(
        '#type' => 'checkbox',
        '#title' => t('Hide Quantity'),
        '#default_value' => variable_get('av_c_hide_quantity', 1),
        '#description' => t('Hide quantity field in cart confirmation and shopping cart form views and not allow more than one same product in the cart'),
    );
    $form['#validate'][] = 'commerce_availability_validate';
    return system_settings_form($form);
}

function commerce_availability_validate($form, &$form_state) {
    $values = $form_state['values'];
    foreach ($values as $name => $value) {
        if (strpos($name, 'av_n') === 0 && (!is_numeric($value) || $value < 0)) {
            form_set_error($name, check_plain(t('You must enter a positive integer or 0 for: !name field', array('!name' => $name))));
        }
        elseif (strpos($name, 'av_f') === 0 && empty($value)) {
        form_set_error($name, check_plain(t('Empty value for: !name. You must select a field.', array('!name' => $name))));
        }
    }
}
