/**
 * @file
 * Commerce Availability javascript
 */

(function($) {
    "use strict";
    var last_context = 1;
    var dateLimit = new Date();
    dateLimit.setDate(dateLimit.getDate() + 365);
    var today = new Date();

    Drupal.behaviors.commerce_availability = {
        attach : function(context, settings) { 
            if ($('input[name="product_id"]', context).length > 0) {
                n = $('form').attr("id").split("--")[1];
                if (n > last_context) last_context++;
                else if (typeof n !== 'undefined') return;
                $.post(settings.basePath + 'commerce_availability_ajax', {
                    pid: $('input[name="product_id"]', context).val()
                }, function(data) {
                    if (data !== 'null') {
                        Drupal.settings.available_dates = $.parseJSON(data);
                        _ca_setFirstAvailableDate(new Date(), dateLimit);
                    }
                    else {
                        Drupal.settings.available_dates = [{}];
                    }
                });
                var picker_id = $(".date-clear").attr('id');
                Drupal.settings.datePopup[picker_id].settings.numberOfMonths = 2;
                Drupal.settings.datePopup[picker_id].settings.firstDay = 1;
                Drupal.settings.datePopup[picker_id].settings.maxDate = '+12M';
                Drupal.settings.datePopup[picker_id].settings.minDate = 0;
                Drupal.settings.datePopup[picker_id].settings.beforeShowDay = _ca_getAvailability;
                Drupal.settings.datePopup[picker_id].settings.onClose = _ca_checkAvailability;
            }
        }
    }

    var _ca_getAvailability = function(date) {
        var day = $.datepicker.formatDate("yy-mm-dd", date);
        var today = $.datepicker.formatDate("yy-mm-dd", new Date());
        if ($(Drupal.settings.available_dates).length > 0) {
            if(Drupal.settings.available_dates[day]) {
                return [false, 'unavailable', Drupal.t('Unavailable day')];
            }
        }
        return [true];
    }

    var _ca_checkAvailability = function() {
        var date = $('.date-clear').datepicker('getDate');
        var day = $.datepicker.formatDate("yy-mm-dd", date);
        if ($(Drupal.settings.available_dates).length > 0) {
            if(Drupal.settings.available_dates[day] || (date.getTime() < today.getTime())) {
                _ca_setFirstAvailableDate(new Date(), dateLimit);
            }
        }
    }

    var _ca_setFirstAvailableDate = function(date, dateLimit) {
        if(_ca_getAvailability(date)[0] == true) {
            var picker_id = $(".date-clear").attr('id');
            var dateFormat = Drupal.settings.datePopup[picker_id].settings.dateFormat;
            var day = $.datepicker.formatDate(dateFormat, date);
            $('.date-clear').val(day);
        }
        else {
            nextDay = new Date(date);
            nextDay.setDate(date.getDate() + 1);
            if(nextDay >= dateLimit) {
                return;
            }
            _ca_setFirstAvailableDate(nextDay, dateLimit);
         }
    }

})(jQuery);
